/**
 * Notifications utilities
 * 
 * @author Pierre Hubert
 */

import { NotifEventType, Notif, NotifElemType } from "../entities/Notification";
import { NotificationsHelper } from "../helpers/NotificationsHelper";
import { time } from "./DateUtils";

export class NotificationsUtils {

	/**
	 * Create a notification about a post
	 * 
	 * @param fromUser Source user ID
	 * @param postID Target post ID
	 * @param action Action to notify
	 */
	public static async CreatePostNotification(fromUser: number, postID: number, action: NotifEventType) {
		await NotificationsHelper.Push(new Notif({
			timeCreate: time(),
			fromUserID: fromUser,
			onElemID: postID,
			onElemType: NotifElemType.POST,
			type: action
		}));
	}


	/**
	 * Create & push friendship request notification
	 * 
	 * @param fromUser Source user ID
	 * @param toUser Destination user ID
	 * @param action The kind of action
	 */
	public static async CreateFriendsNotifications(fromUser: number, toUser: number, action: NotifEventType) {
		// TODO : Delete all the previous notifications

		// PUsh the notification
		await NotificationsHelper.Push(new Notif({
			fromUserID: fromUser,
			destUserID: toUser,
			onElemID: fromUser, // Same as fromUser
			onElemType: NotifElemType.FRIENDSHIP_REQUEST,
			type: action
		}));
	}

}